@@ -12,7 +12,7 @@ use DBIx::Log4perl::Constants qw (:masks $LogMask);
 use DBIx::Log4perl::db;
 use DBIx::Log4perl::st;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 require Exporter;
 our @ISA = qw(Exporter DBI);		# look in DBI for anything we don't do
 
@@ -32,12 +32,21 @@ our %EXPORT_TAGS= (masks => \@EXPORT_MASKS);
 Exporter::export_ok_tags('masks'); # all tags must be in EXPORT_OK
 
 
+BEGIN {
+    # when Log4perl logs where the log message was output get it to ignore
+    # the lowest 2 levels of the stack i.e. DBIx::Log4perl.
+    $Log::Log4perl::caller_depth = 2;
+}
+
 my $glogger;
 
 sub _dbix_l4p_debug {
     my ($self, $thing, @args) = @_;
 
     my $h = $self->{private_DBIx_Log4perl};
+
+    return unless $h->{logger}->is_debug();
+
     $Data::Dumper::Indent = 0;
 
     if (scalar(@args) > 1) {
@@ -596,9 +605,8 @@ use:
   log4perl.appender.A1.layout.ConversionPattern=%d %p> %F{1}:%L %M - %m%n
 
 to make Log4perl prefix the line with a timestamp, module name and
-filename but the latter two are not too useful since they will always
-report a position in DBIx::Log4perl instead of your module. I'd
-welcome any suggestion to get around this.
+filename. DBIx::Log4perl sets $Log::Log4perl::caller_depth=2 in it's
+BEGIN so Log4perl ignores the two lowest levels in the stack.
 
 =head1 FORMAT OF LOG
 
@@ -774,8 +782,9 @@ This is the same issue as above for $h->{Username}.
 In DBD::ODBC 1.13 you cannot obtain ParamValues after an execute has
 failed. I believe this is because DBD::ODBC insists on describing a
 result-set before returning ParamValues and that is not necessary for
-ParamValues. I've mailed Jeff Urlwin about this and he is looking
-into it.
+ParamValues.
+
+Fixed in 1.14.
 
 =head2 DBD::mysql and ParamArrays
 
