@@ -5,7 +5,7 @@ package DBIx::Log4perl::Constants;
 require Exporter;
 our @ISA = qw(Exporter);
 
-use constant DBIX_L4P_LOG_DEFAULT => 0x5d;
+use constant DBIX_L4P_LOG_DEFAULT => 0xdd;
 use constant DBIX_L4P_LOG_ALL => 0xffffff;
 use constant DBIX_L4P_LOG_INPUT => 0x1;
 use constant DBIX_L4P_LOG_OUTPUT => 0x2;
@@ -14,6 +14,7 @@ use constant DBIX_L4P_LOG_TXN => 0x8;
 use constant DBIX_L4P_LOG_ERRCAPTURE => 0x10;
 use constant DBIX_L4P_LOG_WARNINGS => 0x20;
 use constant DBIX_L4P_LOG_ERRORS => 0x40;
+use constant DBIX_L4P_LOG_DBDSPECIFIC => 0x80;
 
 our $LogMask = DBIX_L4P_LOG_DEFAULT;
 
@@ -28,6 +29,7 @@ our @EXPORT_MASKS = qw(DBIX_L4P_LOG_DEFAULT
 		       DBIX_L4P_LOG_ERRCAPTURE
 		       DBIX_L4P_LOG_WARNINGS
 		       DBIX_L4P_LOG_ERRORS
+		       DBIX_L4P_LOG_DBDSPECIFIC
 		     );
 our %EXPORT_TAGS = (masks => \@EXPORT_MASKS);
 Exporter::export_ok_tags('masks');
