@@ -55,14 +55,16 @@ sub execute {
     # and put them back after using the second sth (ensuring we temporarily
     # turn off any error handler to avoid set_err calling them again).
     #
-    if (($h->{logmask} & DBIX_L4P_LOG_DBDSPECIFIC) &&
+    if (($h->{logger}->is_debug()) &&
+        ($h->{logmask} & DBIX_L4P_LOG_DBDSPECIFIC) &&
     	($h->{driver} eq 'Oracle') && (!$h->{dbd_specific})) {
 	my ($errstr, $err, $state) = (
 	    $sth->errstr, $sth->err, $sth->state);
     	$h->{dbd_specific} = 1;
     	my $dbh = $sth->FETCH('Database');
-    	my @d = $dbh->func('dbms_output_get');
-    	$sth->_dbix_l4p_debug('dbms', @d) if scalar(@d);
+        
+        my @lines = $dbh->func('dbms_output_get');
+    	$sth->_dbix_l4p_debug('dbms', @lines) if (scalar(@lines) > 0);
     	$h->{dbd_specific} = 0;
 	{
 	    local $sth->{HandleError} = undef;
@@ -131,7 +133,8 @@ sub execute_array {
 		    push @plist, $pa->{$p};
 		}
 	    }
-	    $h->{logger}->error(sub {"\t for " . join(',', @plist)});
+	    $h->{logger}->error(sub {"\t for " .
+				     join(',', map(DBI::neat($_), @plist))});
 	}
     } elsif ($executed) {
 	if ((defined($sth->{NUM_OF_FIELDS})) || # result-set
